@@ -84,7 +84,7 @@ class Freebox(IPlugin):
 ##>>> x[2:-2]
 ##'llo Worl'
 							resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,ind1))
-							time.sleep(2)		
+	##						time.sleep(2)		
 							resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,ind2))
 		##					log.msg("resp  :  %s" % (resp))
 				if rs['idx_sec'] == "1":
